"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.env = void 0;
const Log_1 = require("./Log");
/**
 * Used to ensure a particular environment variable has a value
 * @param name The name of the environment variable
 * @param value The assumed value of the environment variable
 */
function assertEnvVar(name, value) {
    if (!value) {
        Log_1.newLogUtil({ color: true }).error(`missing the following required environment variable: ${name}`);
        process.exit(1);
    }
}
let currentEnv = null;
/**
 * Returns the current running environment
 * This can only be "production", "development", or "testing"
 */
function getEnv() {
    if (currentEnv) {
        return currentEnv;
    }
    let val = '';
    if (process.env.NODE_ENV) {
        val = String(process.env.NODE_ENV);
    }
    else if (process.env.ENV) {
        val = String(process.env.ENV);
    }
    const envValue = val ? val.trim().toLowerCase() : 'production';
    if (!['production', 'development', 'testing'].includes(envValue)) {
        Log_1.newLogUtil({ color: true }).error(`${envValue} is not a valid environemnt type for bf-lib-node`, { color: true });
        process.exit(1);
    }
    currentEnv = envValue;
    return currentEnv;
}
/**
 * Determine if the application is running in a development environment
 */
function isDevelopment() {
    return getEnv() === 'development';
}
/**
 * Determine if the application is running in a production environment
 */
function isProduction() {
    return getEnv() === 'production';
}
/**
 * Determine if the application is running in a testing environment
 */
function isTesting() {
    return getEnv() === 'testing';
}
exports.env = {
    assertEnvVar,
    getEnv,
    isDevelopment,
    isProduction,
    isTesting,
};
