"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.newLogUtil = void 0;
const chalk_1 = require("chalk");
const os_1 = require("os");
const util_1 = require("util");
const Env_1 = require("./Env");
/**
 * Create a logging utility
 */
function newLogUtil(options) {
    const defaultOptions = {
        appName: 'bf-lib-node',
    };
    if (options) {
        if (options.appName) {
            defaultOptions.appName = options.appName;
        }
        defaultOptions.color = typeof options.color === 'boolean' ? options.color : Env_1.env.isDevelopment();
        if (options.stdout) {
            defaultOptions.stdout = options.stdout;
        }
        if (options.stderr) {
            defaultOptions.stderr = options.stderr;
        }
    }
    else {
        defaultOptions.color = Env_1.env.isDevelopment();
    }
    const stdout = options && options.stdout ? options.stdout : process.stdout;
    return {
        debug: logLevel('DEBUG', chalk_1.magenta, defaultOptions),
        info: logLevel('INFO', chalk_1.green, defaultOptions),
        warn: logLevel('WARN', chalk_1.yellow, defaultOptions),
        error: logLevel('ERROR', chalk_1.red, defaultOptions),
        inspect: (data) => stdout.write(`${util_1.inspect(data, false, null, true)}${os_1.EOL}`),
        new: (newOptions) => newLogUtil(newOptions),
    };
}
exports.newLogUtil = newLogUtil;
/**
 * Used to separate different levels of logging
 */
function logLevel(level, color, defaultOptions) {
    const defaultStdout = defaultOptions.stdout ? defaultOptions.stdout : process.stdout;
    const defaultStderr = defaultOptions.stderr ? defaultOptions.stderr : process.stderr;
    return (message, options) => {
        const useColor = options && options.color ? true : defaultOptions.color;
        const messageDate = new Date();
        const day = messageDate.getUTCDate();
        const monthIndex = messageDate.getUTCMonth();
        const year = messageDate.getUTCFullYear();
        const time = messageDate.toISOString().split('T')[1].split('.')[0];
        const logDate = `${monthNames[monthIndex].substr(0, 3)} ${day} ${year} ${time}`;
        const type = useColor ? color(level) : level;
        const appName = options && options.appName ? options.appName : defaultOptions.appName;
        const meta = `${logDate} ${os_1.hostname()} ${appName}[${process.pid}]:`;
        const logMessage = `[${type}] ${useColor ? chalk_1.grey(meta) : meta} ${message}`;
        if (level === 'ERROR' || level === 'WARN') {
            const stderr = options && options.stderr ? options.stderr : defaultStderr;
            stderr.write(`${logMessage}${os_1.EOL}`);
        }
        else {
            const stdout = options && options.stdout ? options.stdout : defaultStdout;
            stdout.write(`${logMessage}${os_1.EOL}`);
        }
    };
}
/* ~~~ Helper Functions and Constants ~~~ */
const monthNames = [
    'January',
    'February',
    'March',
    'April',
    'May',
    'June',
    'July',
    'August',
    'September',
    'October',
    'November',
    'December',
];
