"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.authProvider = void 0;
const bf_lib_1 = require("bf-lib");
const dotenv_1 = require("dotenv");
const Auth_1 = require("./auth/Auth");
exports.authProvider = Auth_1.default;
const common_1 = require("./common");
dotenv_1.config();
async function bflib(settings) {
    validateSettings(settings);
    const log = common_1.newLogUtil();
    const logging = {
        logger: log,
        mask: common_1.env.isProduction() ? ['debug'] : [],
    };
    const auth = await Auth_1.default(settings.client);
    const client = { type: bf_lib_1.ClientType.NODE };
    const lib = await bf_lib_1.default({ ...settings, client, logging, auth });
    return Object.freeze({
        get api() {
            return lib.api;
        },
        get auth() {
            return lib.auth;
        },
        get module() {
            return lib.module;
        },
        get multitool() {
            return lib.multitool;
        },
        getAccessToken() {
            return auth.getAccessToken();
        },
        log,
    });
}
exports.default = bflib;
function validateSettings(settings) {
    if (!isObject(settings)) {
        exit('failed to start bf-lib-node because no settings were supplied');
    }
    if (!isObject(settings.client)) {
        exit('failed to start bf-lib-node because no client settings were supplied');
    }
    if (!isObject(settings.nexus)) {
        exit('failed to start bf-lib-node because no nexus settings were supplied');
    }
    if (Auth_1.hasApiKeySettings(settings.client)) {
        if (!isValidString(settings.client.apiKey)) {
            exit('failed to start bf-lib-node because an invalid apiKey was supplied');
        }
    }
    else {
        if (!isValidString(settings.client.clientId)) {
            exit('failed to start bf-lib-node because an invalid clientId was supplied');
        }
        if (!isValidString(settings.client.clientSecret)) {
            exit('failed to start bf-lib-node because an invalid clientSecret was supplied');
        }
        if (!isValidString(settings.client.issuerURI)) {
            exit('failed to start bf-lib-node because an invalid issuerUri was supplied supplied');
        }
    }
}
function exit(msg) {
    console.error(msg);
    process.exit(1);
}
function isObject(value) {
    return value && typeof value === 'object';
}
function isValidString(value) {
    return typeof value === 'string' && value.length > 0;
}
